@@ -1,6 +1,7 @@
 from __future__ import unicode_literals
 
 from django.template import Library
+from django.conf import settings
 from django.utils.translation import get_language, override
 from django.core.urlresolvers import reverse, resolve
 
@@ -10,8 +11,13 @@ register = Library()
 @register.assignment_tag
 def translate(obj, language=None):
     language = language or get_language()
+
+    if language == settings.LANGUAGE_CODE:
+        # If the langauge is default return original object
+        return obj
+
     try:
-        return obj.translations.lang(language).get()
+        return obj.translations.get_by_lang(language)
     except:
         return obj
 
@@ -34,4 +40,4 @@ def translate_url(context, path=None, language=None):
         url_full_name = url.url_name
         if url.namespace:
             url_full_name = '%s:%s' % (url.namespace, url_full_name)
-        return reverse(url_full_name, args=url.args, kwargs=url.kwargs)
\ No newline at end of file
+        return reverse(url_full_name, args=url.args, kwargs=url.kwargs)
